summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillalexercsharp.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt/qextscintillalexercsharp.h')
-rw-r--r--qt/qextscintillalexercsharp.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/qt/qextscintillalexercsharp.h b/qt/qextscintillalexercsharp.h
index 97224e1..77971d0 100644
--- a/qt/qextscintillalexercsharp.h
+++ b/qt/qextscintillalexercsharp.h
@@ -3,43 +3,44 @@
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef QEXTSCINTILLALEXERCSHARP_H
-#define QEXTSCINTILLALEXERCSHARP_H
+#ifndef TQEXTSCINTILLALEXERCSHARP_H
+#define TQEXTSCINTILLALEXERCSHARP_H
-#include <qobject.h>
+#include <tqobject.h>
-#include <qextscintillaglobal.h>
-#include <qextscintillalexercpp.h>
+#include <tqextscintillaglobal.h>
+#include <tqextscintillalexercpp.h>
//! \brief The QextScintillaLexerCSharp class encapsulates the Scintilla C#
//! lexer.
-class QEXTSCINTILLA_EXPORT QextScintillaLexerCSharp : public QextScintillaLexerCPP
+class TQEXTSCINTILLA_EXPORT QextScintillaLexerCSharp : public QextScintillaLexerCPP
{
Q_OBJECT
+ TQ_OBJECT
public:
//! Construct a QextScintillaLexerCSharp with parent \a parent and name
//! \a name. \a parent is typically the QextScintilla instance.
- QextScintillaLexerCSharp(QObject *parent = 0,const char *name = 0);
+ QextScintillaLexerCSharp(TQObject *parent = 0,const char *name = 0);
//! Destroys the QextScintillaLexerCSharp instance.
virtual ~QextScintillaLexerCSharp();
@@ -51,31 +52,31 @@ public:
//! \a style.
//!
//! \sa paper()
- QColor color(int style) const;
+ TQColor color(int style) const;
//! Returns the end-of-line fill for style number \a style.
bool eolFill(int style) const;
//! Returns the font for style number \a style.
- QFont font(int style) const;
+ TQFont font(int style) const;
//! Returns the set of keywords for the keyword set \a set recognised
//! by the lexer as a space separated string.
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
//! style is invalid for this language then QString::null is returned.
//! This is intended to be used in user preference dialogs.
- QString description(int style) const;
+ TQString description(int style) const;
//! Returns the background colour of the text for style number
//! \a style.
//!
//! \sa color()
- QColor paper(int style) const;
+ TQColor paper(int style) const;
private:
-#if defined(Q_DISABLE_COPY)
+#if defined(TQ_DISABLE_COPY)
QextScintillaLexerCSharp(const QextScintillaLexerCSharp &);
QextScintillaLexerCSharp &operator=(const QextScintillaLexerCSharp &);
#endif
@@ -51,31 +52,31 @@ public:
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
- //! style is invalid for this language then QString::null is returned.
+ //! style is invalid for this language then TQString() is returned.
//! This is intended to be used in user preference dialogs.